@@ -1,7 +1,7 @@
 from numerous_report_generator.report import Report
 from pathlib import Path
 
-def get_client(auto_generated, instance_id, path_str='..'):
+def get_client(auto_generated, instance_id, path_str='../..'):
 
     if auto_generated:
         from numerous_api_client.client import NumerousClient
@@ -21,8 +21,8 @@ def get_report(client, template, report_filename):
 
     return report
     
-def get_report_with_client(auto_generated, template, report_filename, instance_id):
-    client = get_client(auto_generated, instance_id)
+def get_report_with_client(auto_generated, template, report_filename, instance_id, path_str='../..'):
+    client = get_client(auto_generated, instance_id, path_str=path_str)
     report = get_report(client, template, report_filename)
     return client, report
     
